nengolib\.stats\.ScatteredHypersphere
=====================================

.. currentmodule:: nengolib.stats

.. autoattribute:: nengolib.stats.sphere

.. autoattribute:: nengolib.stats.ball

.. autoclass:: ScatteredHypersphere
